<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       TS Poll
 * @since      1.7.0
 *
 * @package    TS_Poll
 * @subpackage TS_Poll/admin
 */
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    TS_Poll
 * @subpackage TS_Poll/admin
 * @author     TS Poll <TS Poll>
 */
class ts_poll_admin extends ts_poll_function {
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.7.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;
	/**
	 * The version of this plugin.
	 *
	 * @since    1.7.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.7.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public $ts_poll_question_obj;
	public $tsp_build;
	public $tsp_build_proporties;
	public $tsp_build_id;
	private $tsp_page_slug;
	private $tsp_themes;
	private $tsp_themes_links;
	protected $tsp_function_class;
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		if ( isset( $_GET ) && isset( $_GET['page'] ) ) {
			if ( 'ts-poll' === $_GET['page'] || 'ts-poll-builder' === $_GET['page'] ) {
				$this->tsp_page_slug = $_GET['page'];
			}
		}
		if ( 'ts-poll-builder' === $this->tsp_page_slug && is_admin() ) {
			$this->tsp_themes = array(
				'standard-poll'           => 'Standard Poll',
				'image-poll'              => 'Image Poll',
				'video-poll'              => 'Video Poll',
				'standard-without-button' => 'Standard Without Button',
				'image-without-button'    => 'Image Without Button',
				'video-without-button'    => 'Video Without Button',
				'image-in-question'       => 'Image in Question',
				'video-in-question'       => 'Video in Question',
			);
			if ( isset( $_GET['tsp-id'] ) || isset( $_GET['tsp-theme'] ) ) {
				$this->tsp_function_class = new ts_poll_function();
				$tspoll_icon_swap_arr     = array( 'ts_poll_i_it', 'ts_poll_ch_tbc', 'ts_poll_ch_tac', 'ts_poll_vt_it', 'ts_poll_vb_it', 'ts_poll_rb_it', 'ts_poll_p_bb_it', 'ts_poll_bb_it', 'ts_poll_pop_it', 'ts_poll_play_it' );
				if ( isset( $_GET['tsp-id'] ) && is_numeric( $_GET['tsp-id'] ) && is_int( (int) $_GET['tsp-id'] ) && (int) $_GET['tsp-id'] > 0 ) {
					global $wpdb;
					$ts_poll_check = false;
					$ts_poll_table = esc_sql( $wpdb->prefix . 'ts_poll_questions' );
					$tsp_sql       = 'SELECT * FROM ' . $ts_poll_table . ' WHERE id = ' . $_GET['tsp-id'];
					$ts_poll_check = $wpdb->get_row( $tsp_sql, ARRAY_A );
					if ( is_array( $ts_poll_check ) ) {
						$ts_poll_check['Question_Title'] = html_entity_decode( htmlspecialchars_decode( $ts_poll_check['Question_Title'] ), ENT_QUOTES );
						$tsp_ndecoded_style              = json_decode( $ts_poll_check['Question_Style'], true );
						$tsp_ndecoded_settings           = json_decode( $ts_poll_check['Question_Settings'], true );

						foreach ( $tsp_ndecoded_style as $key => $value ) {
							$tsp_ndecoded_style[ $key ] = html_entity_decode( htmlspecialchars_decode( $value ), ENT_QUOTES );
						}
						foreach ( $tsp_ndecoded_settings as $key => $value ) {
							$tsp_ndecoded_settings[ $key ] = html_entity_decode( htmlspecialchars_decode( $value ), ENT_QUOTES );
						}
						$ts_poll_check['Question_Style']    = json_encode( $tsp_ndecoded_style, true );
						$ts_poll_check['Question_Settings'] = json_encode( $tsp_ndecoded_settings, true );
						$ts_poll_answers_table              = esc_sql( $wpdb->prefix . 'ts_poll_answers' );
						$tsp_sqla                           = 'SELECT * FROM ' . $ts_poll_answers_table . ' WHERE Question_id = ' . (int) $_GET['tsp-id'];
						$ts_poll_check_answers              = $wpdb->get_results( $tsp_sqla, ARRAY_A );
						foreach ( $ts_poll_check_answers as $key => $value ) {
							$ts_poll_check_answers[ $key ]['Answer_Title'] = html_entity_decode( htmlspecialchars_decode( $value['Answer_Title'] ), ENT_QUOTES );
						}
						$ts_poll_check['Question_Answers'] = $ts_poll_check_answers;
						$ts_poll_check['Question_Style']   = json_decode( $ts_poll_check['Question_Style'], true );
						foreach ( $tspoll_icon_swap_arr as $key => $value ) {
							if ( array_key_exists( $value, $ts_poll_check['Question_Style'] ) ) {
								$ts_poll_check['Question_Style'][ $value ] = $this->tsp_function_class->tsp_icon_swap( $value, $ts_poll_check['Question_Style'][ $value ], false );
							}
						}
						$this->tsp_build            = 'edit';
						$this->tsp_build_proporties = $ts_poll_check;
						$this->tsp_build_id         = sanitize_text_field( $_GET['tsp-id'] );
					} else {
						$this->tsp_build = 'not';
					}
				} elseif ( isset( $_GET['tsp-theme'] ) && array_key_exists( $_GET['tsp-theme'], $this->tsp_themes ) ) {
					$this->tsp_build_id                                     = sanitize_text_field( $_GET['tsp-theme'] );
					$this->tsp_build                                        = 'edit';
					$tspoll_theme_json                                      = $this->tsp_function_class->tsp_get_all_params();
					$tspoll_theme_json['Question_Param']['TS_Poll_Q_Theme'] = $this->tsp_themes[ $this->tsp_build_id ];
					$tspoll_theme_json['Answers']                           = array_values( $tspoll_theme_json['Answers'] );
					foreach ( $tspoll_theme_json['Answers'] as $key => $value ) {
						$tspoll_theme_json['Answers'][ $key ]['Question_id']  = $this->tsp_build_id;
						$tspoll_theme_json['Answers'][ $key ]['Answer_Param'] = json_encode( $tspoll_theme_json['Answers'][ $key ]['Answer_Param'] );
					}
					$tspoll_themes_result = $this->tsp_function_class->tsp_get_theme_params( $this->tsp_build_id );
					foreach ( $tspoll_icon_swap_arr as $key => $value ) {
						if ( array_key_exists( $value, $tspoll_themes_result ) ) {
							$tspoll_themes_result[ $value ] = $this->tsp_function_class->tsp_icon_swap( $value, $tspoll_themes_result[ $value ], false );
						}
					}
					$this->tsp_build_proporties = array(
						'id'                => $this->tsp_build_id,
						'Question_Title'    => $tspoll_theme_json['Question_Title'],
						'Question_Settings' => json_encode( $tspoll_theme_json['Question_Settings'] ),
						'Question_Param'    => json_encode( $tspoll_theme_json['Question_Param'] ),
						'Question_Style'    => $tspoll_themes_result,
						'Answers_Sort'      => $tspoll_theme_json['Answers_Sort'],
						'created_at'        => date( 'd.m.Y h:i:sa' ),
						'updated_at'        => date( 'd.m.Y h:i:sa' ),
						'Question_Answers'  => $tspoll_theme_json['Answers'],
					);
				} else {
					$this->tsp_build = '404';
				}
			} else {
				$this->tsp_build        = 'new';
				$this->tsp_themes_links = array(
					'standard-poll'           => 'wp-poll-vote-standard',
					'image-poll'              => 'wp-poll-vote-standard-image',
					'video-poll'              => 'wp-poll-vote-standard-video',
					'standard-without-button' => 'wp-poll-vote-standard-without-button',
					'image-without-button'    => 'wp-poll-vote-standard-image-without-button',
					'video-without-button'    => 'wp-poll-vote-standard-video-without-button',
					'image-in-question'       => 'wp-poll-vote-image-in-question',
					'video-in-question'       => 'wp-poll-vote-video-in-question',
				);

			}
		}
		add_action( 'wp_ajax_tsp_check_attachment', array( $this, 'tsp_get_attachment_callback' ) );
		add_action( 'wp_ajax_tsp_get_attachment_id', array( $this, 'tsp_get_attachment_id' ) );
		add_action( 'wp_ajax_tsp_save_question', array( $this, 'tsp_save_question' ) );
		add_filter( 'plugin_action_links_' . TS_POLL_BASE, array( $this, 'tsp_add_action_link' ) );
		add_filter( 'set-screen-option', array( $this, 'set_screen' ), 10, 3 );
	}
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.7.0
	 */
	public function tsp_add_action_link( $links ) {
		$links['tspoll_support'] = sprintf( '<a href="%s" style="color: #8bc34a;font-weight: bold;" target="_blank">%s</a>', esc_url( 'https://wordpress.org/support/plugin/poll-wp/' ), esc_attr__( 'Support', 'tspoll' ) );
		$links['tspoll_go_pro']  = sprintf( '<a href="%s" style="color: #ff0000;font-weight: bold;" target="_blank">%s</a>', esc_url( 'https://total-soft.com/wp-poll/' ), esc_attr__( 'Go Pro', 'tspoll' ) );
		return $links;
	}

	public function enqueue_styles() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in ts_poll_loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The ts_poll_loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( 'ts_poll_fonts', plugin_dir_url( __DIR__ ) . 'fonts/ts_poll-fonts.css', array(), time(), 'all' );
		if ( 'ts-poll' === $this->tsp_page_slug ) {
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/ts_poll-admin.css', array(), time(), 'all' );
		}
		if ( 'ts-poll-builder' === $this->tsp_page_slug ) {
			wp_enqueue_style( 'tspoll_toastr', plugin_dir_url( __FILE__ ) . 'css/toastr.min.css', array(), time(), 'all' );
			wp_enqueue_style( 'tspoll_builder', plugin_dir_url( __FILE__ ) . 'css/ts_poll-builder.css', array(), time(), 'all' );
			wp_add_inline_style( 'tspoll_builder', sprintf( ':root{ --tspoll_click_for : "%s"; }', esc_attr__( 'Click for change text', 'tspoll' ) ) );
			if ( 'edit' === $this->tsp_build ) {
				wp_enqueue_style( "tsp_context-menu", plugin_dir_url( __FILE__ ) . 'css/jquery.contextMenu.css', array(), time(), 'all' );
				wp_enqueue_style( 'tsp_builder', plugin_dir_url( __FILE__ ) . 'css/ts_poll-edit.css', array(), time(), 'all' );
				wp_enqueue_style( 'tspoll_icon_picker', plugin_dir_url( __FILE__ ) . 'css/tsp-aesthetic-icon-picker.css', array(), time(), 'all' );
				wp_enqueue_style( 'tspoll_color_picker', plugin_dir_url( __FILE__ ) . 'css/tsp-spectrum.css', array(), time(), 'all' );
				wp_enqueue_style( 'tspoll_datatables', plugin_dir_url( __FILE__ ) . 'css/vanilla-dataTables.css', array(), time(), 'all' );
			} elseif ( 'new' === $this->tsp_build ) {
				wp_enqueue_style( 'tsp_builder', plugin_dir_url( __FILE__ ) . 'css/ts_poll-new.css', array(), time(), 'all' );
			}
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.7.0
	 */

	public function enqueue_scripts() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in ts_poll_loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The ts_poll_loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( 'ts-poll' === $this->tsp_page_slug ) {
			wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/ts_poll-admin.js', array( 'jquery' ), time(), false );
			wp_localize_script(
				$this->plugin_name,
				'tspoll_admin_json',
				array(
					'copy'          => esc_html__( 'Copy', 'tspoll' ),
					'delete'        => esc_html__( 'Delete', 'tspoll' ),
					'copy_action'   => esc_html__( 'Do you really want to copy this poll?', 'tspoll' ),
					'delete_action' => esc_html__( 'Do you really want to delete this poll? This process cannot be undone.', 'tspoll' ),
					'copied'        => esc_html__( 'Copied', 'tspoll' ),
				)
			);
		}
		if ( 'ts-poll-builder' === $this->tsp_page_slug ) {
			wp_enqueue_media();
			wp_enqueue_script( "tsp_context-menu", plugin_dir_url( __FILE__ ) . 'js/jquery.contextMenu.js', array( 'jquery' ), time(), true );
			wp_register_script( 'tspoll_toastr', plugin_dir_url( __FILE__ ) . 'js/toastr.min.js', array(), time(), false );
			wp_enqueue_script( 'tspoll_color_picker', plugin_dir_url( __FILE__ ) . 'js/tsp-spectrum.js', array(), time(), false );
			wp_enqueue_script( 'tspoll_datatables', plugin_dir_url( __FILE__ ) . 'js/vanilla-dataTables.js', array(), time(), false );
			wp_localize_script(
				'tspoll_datatables',
				'tspoll_translations',
				array(
					'search'          => esc_html__( 'Search', 'tspoll' ),
					'entries_page'    => esc_html__( 'entries per page', 'tspoll' ),
					'entries_nofound' => esc_html__( 'No entries found', 'tspoll' ),
					'show'            => esc_html__( 'Showing', 'tspoll' ),
					'to'              => esc_html__( 'to', 'tspoll' ),
					'of'              => esc_html__( 'of', 'tspoll' ),
					'entries'         => esc_html__( 'entries', 'tspoll' ),
				)
			);
			wp_enqueue_script( 'tspoll_builder', plugin_dir_url( __FILE__ ) . 'js/ts_poll-builder.js', array( 'jquery', 'tspoll_toastr', 'jquery-ui-sortable', 'tspoll_color_picker', 'tspoll_datatables', 'tsp_context-menu' ), time(), true );
			if ( 'edit' === $this->tsp_build ) {
				$tsp_answers                                    = $tsp_votes = $tsp_colors = array();
				$this->tsp_build_proporties['Question_Answers'] = array_column( $this->tsp_build_proporties['Question_Answers'], null, 'id' );
				foreach ( $this->tsp_build_proporties['Question_Answers'] as $key => $value ) :
					$TS_Poll_Answer_Args = json_decode( $value['Answer_Param'] );
					$tsp_answers[]       = $value['Answer_Title'];
					$tsp_votes[]         = $value['Answer_Votes'];
					$tsp_colors[]        = $TS_Poll_Answer_Args->TotalSoftPoll_Ans_Cl;
					$this->tsp_build_proporties['Question_Answers'][ $key ]['Answer_Param'] = json_decode( $value['Answer_Param'] );
				endforeach;

				wp_localize_script(
					'tspoll_builder',
					'tspoll_builder_json',
					array(
						'ajaxurl'              => admin_url( 'admin-ajax.php' ),
						'tsp_nonce'            => wp_create_nonce( 'tsp_builder_nonce_field' ),
						'tsp_proporties'       => $this->tsp_build_proporties,
						'tsp_id'               => $this->tsp_build_id,
						'tsp_creation'         => isset( $_GET['tsp-theme'] ) ? 'save' : 'update',
						'tsp_answers'          => $tsp_answers,
						'tsp_votes'            => $tsp_votes,
						'tsp_colors'           => $tsp_colors,
						'fonts'                => $this->tsp_function_class->tsp_get_all_fonts(),
						'tsp_svg_move'         => esc_url( plugin_dir_url( __FILE__ ) . 'img/move.svg' ),
						'tsp_svg_remove'       => esc_url( plugin_dir_url( __FILE__ ) . 'img/recycle.svg' ),
						'tsp_svg_edit'         => esc_url( plugin_dir_url( __FILE__ ) . 'img/edit.svg' ),
						'tsp_svg_copy'         => esc_url( plugin_dir_url( __FILE__ ) . 'img/copy.svg' ),
						'tsp_no_img'           => esc_url( plugin_dir_url( __DIR__ ) . 'public/img/tsp_no_img.jpg' ),
						'tsp_no_video'         => esc_url( plugin_dir_url( __DIR__ ) . 'public/img/tsp_no_video.png' ),
						'warning'              => esc_html__( 'Warning', 'tspoll' ),
						'info'                 => esc_html__( 'Info', 'tspoll' ),
						'success'              => esc_html__( 'Success', 'tspoll' ),
						'error'                => esc_html__( 'Error', 'tspoll' ),
						'theme_warning'        => esc_html__( 'You are already choose theme.', 'tspoll' ),
						'theme_choose_warning' => esc_html__( 'Please choose a theme for more experiance.', 'tspoll' ),
						'statistics_warning'   => esc_html__( 'Poll statistics field is pro feature.', 'tspoll' ),
						'results_warning'      => esc_html__( 'Please save poll for getting results.', 'tspoll' ),
						'icon_warning'         => esc_html__( 'Icon for this field required.', 'tspoll' ),
						'thumbnail_warning'    => esc_html__( 'Your selected video has not thumbnail,but you can add image.', 'tspoll' ),
						'link_warning'         => esc_html__( "Your inserted link isn't valid.", 'tspoll' ),
						'image_warning'        => esc_html__( "Your inserted file type isn't image.", 'tspoll' ),
						'save_warning'         => esc_html__( "Your poll isn't saved.", 'tspoll' ),
						'amount_warning'       => esc_html__( 'Minimum amount of answers is 2.', 'tspoll' ),
						'copy_note'            => esc_html__( 'Answer successfully copied.', 'tspoll' ),
						'delete_note'          => esc_html__( 'Answer successfully deleted.', 'tspoll' ),
						'add_note'             => esc_html__( 'New answer successfully added.', 'tspoll' ),
						'shortcode_note'       => esc_html__( 'Shortcode copied.', 'tspoll' ),
						'shortcode_theme_note' => esc_html__( 'Shortcode theme code copied.', 'tspoll' ),
						'thumbnail_info'       => esc_html__( 'Your selected video has thumbnail,but you can change it.', 'tspoll' ),
					)
				);
			}
		}
	}

	public static function set_screen( $status, $option, $value ) {
		return $value;
	}

	function tsp_get_attachment_callback() {
		if ( ! isset( $_POST['tsp_nonce'] ) || $_POST['tsp_nonce'] == '' || ! wp_verify_nonce( $_POST['tsp_nonce'], 'tsp_builder_nonce_field' ) ) {
			wp_send_json_error();
		}
		$attachment_url = sanitize_text_field( $_POST['attachment_url'] );
		if ( is_numeric( attachment_url_to_postid( $attachment_url ) ) && attachment_url_to_postid( $attachment_url ) != 0 ) {
			wp_send_json_success( attachment_url_to_postid( $attachment_url ) );
		} else {
			wp_send_json_error();
		}
	}

	function tsp_get_attachment_id() {
		if ( ! isset( $_POST['tsp_nonce'] ) || $_POST['tsp_nonce'] == '' || ! wp_verify_nonce( $_POST['tsp_nonce'], 'tsp_builder_nonce_field' ) ) {
			wp_send_json_error();
		}
		$attachment_url = sanitize_text_field( $_POST['attachment_url'] );
		$fp             = fopen( $attachment_url, 'rb' );
		if ( $fp ) {
			list($width, $height) = getimagesize( $attachment_url );
			$data                 = array(
				'image'  => esc_url( $attachment_url ),
				'width'  => esc_html( $width ),
				'height' => esc_html( $height ),
			);
			if ( is_numeric( attachment_url_to_postid( $attachment_url ) ) ) {
				$data['id'] = attachment_url_to_postid( $attachment_url );
			}
			wp_send_json_success( $data );
		} else {
			wp_send_json_error();
		}
	}

	function tsp_save_question() {
		if ( ! isset( $_POST['tsp_nonce'] ) || $_POST['tsp_nonce'] == '' || ! wp_verify_nonce( $_POST['tsp_nonce'], 'tsp_builder_nonce_field' ) ) {
			wp_send_json_error( 'TS Poll nonce error.' );
		}
		$tsp_themes_arr     = array(
			'standard-poll'           => 'Standard Poll',
			'image-poll'              => 'Image Poll',
			'video-poll'              => 'Video Poll',
			'standard-without-button' => 'Standard Without Button',
			'image-without-button'    => 'Image Without Button',
			'video-without-button'    => 'Video Without Button',
			'image-in-question'       => 'Image in Question',
			'video-in-question'       => 'Video in Question',
		);
		$tsp_question_id    = sanitize_text_field( $_POST['tsp_id'] );
		$tsp_question_title = sanitize_text_field( htmlentities( stripslashes( $_POST['tsp_question_title'] ), ENT_QUOTES ) );
		if ( is_numeric( $tsp_question_id ) || array_key_exists( $tsp_question_id, $tsp_themes_arr ) ) {
			global $wpdb;
			$tsp_question_table    = $wpdb->prefix . 'ts_poll_questions';
			$tsp_answers_table     = $wpdb->prefix . 'ts_poll_answers';
			$tsp_answers           = json_decode( json_encode( $_POST['tsp_answers'] ), true );
			$tsp_answers_sort      = json_decode( json_encode( $_POST['tsp_answers_sort'] ), true );
			$tsp_question_styles   = json_decode( json_encode( $_POST['tsp_question_styles'] ), true );
			$tsp_question_params   = json_decode( json_encode( $_POST['tsp_question_params'] ), true );
			$tsp_question_settings = json_decode( json_encode( $_POST['tsp_question_settings'] ), true );
			$tsp_deleted_answers   = json_decode( json_encode( $_POST['tsp_deleted_answers'] ), true );
			$tsp_response          = array();
			$tsp_sort_arr          = array();
			foreach ( $tsp_question_styles as $key => $value ) {
				$tsp_question_styles[ $key ] = sanitize_text_field( htmlentities( stripslashes( $value ), ENT_QUOTES ) );
			}
			foreach ( $tsp_question_params as $key => $value ) {
				if ( $key == 'TS_Poll_Q_Theme' ) {
					$tsp_question_params[ $key ] = sanitize_text_field( $value );
				} else {
					$tsp_question_params[ $key ] = sanitize_url( $value );
				}
			}
			foreach ( $tsp_question_settings as $key => $value ) {
				$tsp_question_settings[ $key ] = sanitize_text_field( htmlentities( stripslashes( $value ), ENT_QUOTES ) );
			}
			if ( array_key_exists( $tsp_question_id, $tsp_themes_arr ) ) {
				$wpdb->insert(
					$tsp_question_table,
					array(
						'id'                => '',
						'Question_Title'    => $tsp_question_title,
						'Question_Param'    => json_encode( $tsp_question_params ),
						'Question_Style'    => json_encode( $tsp_question_styles ),
						'Question_Settings' => json_encode( $tsp_question_settings ),
						'Answers_Sort'      => '',
						'created_at'        => date( 'd.m.Y h:i:sa' ),
						'updated_at'        => date( 'd.m.Y h:i:sa' ),
					),
					array( '%d', '%s', '%s', '%s', '%s', '%s', '%s', '%s' )
				);
				$tsp_new_question_id = $wpdb->insert_id;
				foreach ( $tsp_answers_sort as $key => $value ) {
					$tsp_arr_key      = sanitize_text_field( $value );
					$tsp_answer_title = htmlentities( sanitize_text_field( stripslashes( $tsp_answers[ $tsp_arr_key ]['Answer_Title'] ) ), ENT_QUOTES );
					foreach ( $tsp_answers[ $tsp_arr_key ]['Answer_Param'] as $param_key => $param_value ) {
						if ( $param_key == 'TotalSoftPoll_Ans_Vd' || $param_key == 'TotalSoftPoll_Ans_Im' ) {
							$tsp_answers[ $tsp_arr_key ]['Answer_Param'][ $param_key ] = sanitize_url( $param_value );
						} else {
							$tsp_answers[ $tsp_arr_key ]['Answer_Param'][ $param_key ] = sanitize_text_field( $param_value );
						}
					}
					$wpdb->insert(
						$tsp_answers_table,
						array(
							'id'           => '',
							'Question_id'  => (int) $tsp_new_question_id,
							'Answer_Title' => $tsp_answer_title,
							'Answer_Param' => json_encode( $tsp_answers[ $tsp_arr_key ]['Answer_Param'] ),
							'Answer_Votes' => 0,
						),
						array( '%d', '%d', '%s', '%s', '%d' )
					);
					$tsp_sort_arr[] = $wpdb->insert_id;
				}
				$wpdb->update( $tsp_question_table, array( 'Answers_Sort' => implode( ',', $tsp_sort_arr ) ), array( 'id' => (int) $tsp_new_question_id ), array( '%s' ), array( '%d' ) );
				$tsp_response['url'] = add_query_arg( 'tsp-id', $tsp_new_question_id, admin_url( 'admin.php?page=ts-poll-builder' ) );
				wp_send_json_success( $tsp_response );
			} else {
				foreach ( $tsp_answers_sort as $key => $value ) {
					$tsp_arr_key      = sanitize_text_field( $value );
					$tsp_answer_title = sanitize_text_field( htmlentities( stripslashes( $tsp_answers[ $tsp_arr_key ]['Answer_Title'] ), ENT_QUOTES ) );
					foreach ( $tsp_answers[ $tsp_arr_key ]['Answer_Param'] as $param_key => $param_value ) {
						if ( $param_key == 'TotalSoftPoll_Ans_Im' || $param_key == 'TotalSoftPoll_Ans_Vd' ) {
							$tsp_answers[ $tsp_arr_key ]['Answer_Param'][ $param_key ] = sanitize_url( $param_value );
						} else {
							$tsp_answers[ $tsp_arr_key ]['Answer_Param'][ $param_key ] = sanitize_text_field( $param_value );
						}
					}
					if ( strpos( $value, 'new' ) !== false ) {
						$wpdb->insert(
							$tsp_answers_table,
							array(
								'id'           => '',
								'Question_id'  => (int) $tsp_question_id,
								'Answer_Title' => $tsp_answer_title,
								'Answer_Param' => json_encode( $tsp_answers[ $tsp_arr_key ]['Answer_Param'] ),
							),
							array( '%d', '%d', '%s', '%s' )
						);
						$tsp_sort_arr[] = $wpdb->insert_id;
					} else {
						$wpdb->update(
							$tsp_answers_table,
							array(
								'Answer_Title' => $tsp_answer_title,
								'Answer_Param' => json_encode( $tsp_answers[ $tsp_arr_key ]['Answer_Param'] ),
							),
							array( 'id' => (int) $tsp_arr_key ),
							array( '%s', '%s' ),
							array( '%d' )
						);
						$tsp_sort_arr[] = (int) $tsp_arr_key;
					}
				}
				if ( is_array( $tsp_deleted_answers ) && count( $tsp_deleted_answers ) != 0 ) {
					foreach ( $tsp_deleted_answers as $key => $value ) {
						if ( strpos( sanitize_text_field( $value ), 'new' ) === false ) {
							$wpdb->delete(
								$tsp_answers_table,
								array( 'id' => (int) sanitize_text_field( $value ) ),
								array( '%d' )
							);
						}
					}
				}
				$wpdb->update(
					$tsp_question_table,
					array(
						'Question_Title'    => $tsp_question_title,
						'Question_Param'    => json_encode( $tsp_question_params ),
						'Question_Style'    => json_encode( $tsp_question_styles ),
						'Question_Settings' => json_encode( $tsp_question_settings ),
						'Answers_Sort'      => implode( ',', $tsp_sort_arr ),
						'updated_at'        => date( 'd.m.Y h:i:sa' ),
					),
					array( 'id' => (int) $tsp_question_id ),
					array( '%s', '%s', '%s', '%s', '%s', '%s' ),
					array( '%d' )
				);
				$tsp_response['url'] = add_query_arg( 'tsp-id', $tsp_question_id, admin_url( 'admin.php?page=ts-poll-builder' ) );
				wp_send_json_success( $tsp_response );
			}
		} else {
			wp_send_json_error();
		}
	}

	public function tsp_get_field_html( $fieldname, $field, $value ) {
		switch ( $field['type'] ) :
			case 'range':
				return sprintf(
					'
				<div class="length tsp_range_div" data-tsp-min="%1$s" data-tsp-max="%2$s" >
					<div class="tsp_range_div_title tsp_field_title" data-tsp-field="%4$s" data-tsp-length="%3$s(%7$s)">%8$s:</div>
					<label class="tsp_range_label" for="%4$s">%5$s</label>
					<input id="%4$s" class="tsp_range_input" type="range" min="%1$s" max="%2$s" value="%3$s" data-tsp-change="%6$s" data-tsp-param="%7$s"  />
			  	</div>',
					esc_attr( $field['options']['min'] ),
					esc_attr( $field['options']['max'] ),
					esc_attr( $value ),
					esc_attr( $fieldname ),
					esc_attr( $field['label'] ),
					array_key_exists( 'change', $field ) ? esc_attr( $field['change'] ) : '',
					array_key_exists( 'change_param', $field ) ? esc_attr( $field['change_param'] ) : '',
					esc_attr__( 'length', 'tspoll' )
				);
				break;
			case 'text':
			case 'date':
				return sprintf(
					'<div class="tsp_select_div"><span class="tsp_select_div_title tsp_field_title">%s</span><input id="%s" name="%s" type="%s" class="tsp_text_input" value="%s" data-tsp-elem="%s" data-change-prop="%s"/></div>',
					esc_attr( $field['label'] ),
					esc_attr( $fieldname ),
					esc_attr( $fieldname ),
					$field['type'] == 'text' ? 'text' : 'date',
					esc_attr( $value ),
					array_key_exists( 'change_elem', $field ) ? esc_attr( $field['change_elem'] ) : '',
					array_key_exists( 'change_attr', $field ) ? esc_attr( $field['change_attr'] ) : ''
				);
				break;
			case 'color':
				return sprintf(
					'
					<div class="tsp_color_div">
						<label class="tsp_color_label" for="%1$s">%2$s</label>
						<input id="%1$s" name="%1$s" data-tsp-field="color" value="%3$s" data-tsp-change="%4$s" />
					</div>
					',
					esc_attr( $fieldname ),
					esc_attr( $field['label'] ),
					esc_attr( $value ),
					array_key_exists( 'change_prop', $field ) ? esc_attr( $field['change_prop'] ) : ''
				);
				break;
			case 'input-toggle':
				return sprintf(
					'
					<div class="tsp_checkbox_div" data-tsp-check="%6$s" data-tsp-uncheck="%7$s">
						<input class="tsp_checkbox_input" type="checkbox" id="%1$s" name="%1$s" %2$s data-change-elem="%4$s" data-change-prop="%5$s"/>
						<label class="tsp_checkbox_label" for="%1$s">%3$s</label>
					</div>
				',
					esc_attr( $fieldname ),
					$value == 'true' ? esc_attr( 'checked' ) : '',
					esc_attr( $field['label'] ),
					array_key_exists( 'change_elem', $field ) ? esc_attr( $field['change_elem'] ) : '',
					array_key_exists( 'change_attr', $field ) ? esc_attr( $field['change_attr'] ) : '',
					array_key_exists( 'yes', $field['options'] ) ? esc_attr( $field['options']['yes'] ) : 'true',
					array_key_exists( 'no', $field['options'] ) ? esc_attr( $field['options']['no'] ) : 'false'
				);
				break;
			case 'select-icon':
				if ( $fieldname == 'ts_poll_ch_tbc' || $fieldname == 'ts_poll_ch_tac' ) {
					$tsp_function = new ts_poll_function();
				}
				return sprintf(
					'    
				<div class="tsp_icon_picker_div">
					<label id="%s" for="%s">%s</label>
					<div class="ts-poll-icon-picker-wrap" id="%s" data-tsp-field="%s">
						<ul class="icon-picker">
							%s
							<li id="%s" class="ts-poll-select-icon" title="Icon Library"><i class="%s"></i></li>
							<input type="hidden" name="icon_value" id="%s" value="%s" data-tsp-elem="%s" data-change-prop="%s">
						</ul>
					</div>
				</div>	',
					esc_attr( $fieldname ) . '-icon-picker-wrap-label',
					esc_attr( $fieldname ) . '-icon_value',
					esc_attr( $field['label'] ),
					esc_attr( $fieldname ) . '-icon-picker-wrap',
					esc_attr( $fieldname ),
					$fieldname == 'ts_poll_ch_tbc' || $fieldname == 'ts_poll_ch_tac' ? '' : sprintf( '<li class="tsp-set-icon-none" id="%s" title="None"><i class="ts-poll ts-poll-ban"></i></li>', esc_attr( $fieldname ) . '-icon-none' ),
					esc_attr( $fieldname ),
					$fieldname == 'ts_poll_ch_tbc' || $fieldname == 'ts_poll_ch_tac' ? $tsp_function->tsp_icon_get_class_value( $value ) : esc_attr( $value ),
					esc_attr( $fieldname ) . '-icon_value',
					$fieldname == 'ts_poll_ch_tbc' || $fieldname == 'ts_poll_ch_tac' ? $tsp_function->tsp_icon_get_class_value( $value ) : esc_attr( $value ),
					array_key_exists( 'change_elem', $field ) ? esc_attr( $field['change_elem'] ) : '',
					array_key_exists( 'change_attr', $field ) ? esc_attr( $field['change_attr'] ) : ''
				);
				break;
			case 'select':
				$tsp_select = '';
				foreach ( $field['options'] as $opt_value => $opt_name ) {
					$tsp_select .= sprintf(
						'<option value="%s" %s>%s</option>',
						esc_attr( $opt_value ),
						$opt_value == $value ? esc_attr( 'selected' ) : esc_attr( '' ),
						esc_html( $opt_name )
					);
				}

				return sprintf( '<div class="tsp_select_div"><span class="tsp_select_div_title tsp_field_title">%s</span><select id="%s" name="%s" class="%s" data-change-elem="%s" data-change-prop="%s" />%s</select></div>', esc_attr( $field['label'] ), esc_attr( $fieldname ), esc_attr( $fieldname ), array_key_exists( 'change_elem', $field ) ? esc_attr( 'tsp_elem_data' ) : esc_attr( 'tsp_root_elem' ), array_key_exists( 'change_elem', $field ) ? esc_attr( $field['change_elem'] ) : '', array_key_exists( 'change_attr', $field ) ? esc_attr( $field['change_attr'] ) : '', $tsp_select );
				break;
			case 'select-position':
				$tsp_select = '';
				foreach ( $field['options'] as $opt_value => $opt_name ) {
					$tsp_select .= sprintf(
						'<div class="tsp_position_item %s" data-tsp-pos="%s"><p class="tsp_flex_col">%s</p></div>',
						$opt_value == $value || ( 'ts_poll_tv_pos' === $fieldname && $value === "center" && 'full' === $opt_value ) ? esc_attr( 'tsp_active' ) : esc_attr( '' ),
						esc_attr( $opt_value ),
						esc_html( $opt_name )
					);
				}
				return sprintf(
					'
					<div class="tsp_select_div"><span class="tsp_select_div_title tsp_field_title">%s</span>
						<div class="tsp_position_select  tsp_flex_row" data-tsp="%s" data-tsp-select="%s" data-change-elem="%s" data-change-prop="%s">
							%s
						</div>
					</div>	
					',
					esc_attr( $field['label'] ),
					array_key_exists( 'full', $field['options'] ) ? 'btn' : 'div',
					esc_attr( $fieldname ),
					array_key_exists( 'change_elem', $field ) ? esc_attr( $field['change_elem'] ) : '',
					array_key_exists( 'change_attr', $field ) ? esc_attr( $field['change_attr'] ) : '',
					$tsp_select
				);
				break;
			case 'select-position-image':
				$tsp_select = '';
				foreach ( $field['options'] as $opt_value => $opt_name ) {
					$tsp_select .= sprintf(
						'<div class="tsp_position_item %s" data-tsp-pos="%s"><img class="tsp_position_image tsp_flex_col" src="%s"></div>',
						$opt_value == $value ? esc_attr( 'tsp_active' ) : esc_attr( '' ),
						esc_attr( $opt_value ),
						esc_html( $opt_name )
					);
				}
				return sprintf(
					'
					<div class="tsp_select_div"><span class="tsp_select_div_title tsp_field_title">%s</span>
						<div class="tsp_position_select tsp_flex_row" data-tsp="image" data-tsp-select="%s" data-change-elem="%s" data-change-prop="%s">
							%s
						</div>
					</div>	
					',
					esc_attr( $field['label'] ),
					esc_attr( $fieldname ),
					array_key_exists( 'change_elem', $field ) ? esc_attr( $field['change_elem'] ) : '',
					array_key_exists( 'change_attr', $field ) ? esc_attr( $field['change_attr'] ) : '',
					$tsp_select
				);
				break;
			case 'wp_media_image':
				$tsp_image_id_ = $tsp_image_url_ = '';
				if ( $value == '' ) {
					$tsp_image_id_ = $tsp_image_url_ = plugin_dir_url( __DIR__ ) . 'public/img/tsp_no_img.jpg';
				} else {
					if ( is_numeric( attachment_url_to_postid( $value ) ) ) {
						$tsp_image_id_  = attachment_url_to_postid( $value );
						$tsp_image_url_ = $value;
					} else {
						$tsp_image_id_ = $tsp_image_url_ = $value;
					}
				}
				return sprintf(
					'
                  <div class="tsp_img_div_edit">
                    <span class="tsp_field_title">Question image</span>
                    <div class="tsp_img_change">
                      <img src="%1$s">
                      <div class="tsp_img_hover_div">
                        <span>Choose image</span>
                        <input type="text" value="%2$s" id="tsp_answer_attachment_id" style="display:none;">
                      </div>
                      <div class="tsp_img_loading_div tsp_flex_col"  style="display:none;">
                        <img src="%3$s" >
                      </div>
                    </div>
                  </div>
                  ',
					esc_url( $tsp_image_url_ ),
					is_int( $tsp_image_id_ ) ? esc_attr( $tsp_image_id_ ) : esc_url( $tsp_image_id_ ),
					esc_url( plugin_dir_url( __DIR__ ) . 'public/img/tsp_loading.gif' )
				);
				break;
			case 'wp_media_video':
				global $wp_embed;
				$tsp_video_id_ = $tsp_video_url_ = '';
				if ( $value != '' ) {
					if ( is_numeric( attachment_url_to_postid( $value ) ) ) {
						$tsp_video_id_  = attachment_url_to_postid( $value );
						$tsp_video_url_ = $value;
					} else {
						$tsp_video_id_ = $tsp_video_url_ = $value;
					}
				}
				return sprintf(
					'
					<div class="tsp_video_div_edit">
					  <span class="tsp_field_title">Question video</span>
					  <div class="tsp_vd_change">
					  	%5$s
						<img src="%1$s" %2$s>
						<div class="tsp_vd_hover_div">
						  <span>Choose video</span>
						  <input type="text" value="%3$s"  id="tsp_answer_video_attachment_id" style="display:none;">
						</div>
						<div class="tsp_vd_loading_div tsp_flex_col"  style="display:none;">
						  <img src="%4$s" >
						</div>
					  </div>
					</div>
					',
					esc_url( plugin_dir_url( __DIR__ ) . 'public/img/tsp_no_video.png' ),
					$value == '' ? '' : "style='display:none'",
					is_int( $tsp_video_id_ ) || $value == '' ? esc_attr( $tsp_video_id_ ) : esc_url( $tsp_video_id_ ),
					esc_url( plugin_dir_url( __DIR__ ) . 'public/img/tsp_loading.gif' ),
					$value == '' ? '' : do_shortcode( $wp_embed->run_shortcode( '[embed]' . esc_url( $value ) . '[/embed]' ) )
				);
				break;
		endswitch;
	}

	public function screen_option() {
		$option = 'per_page';
		$args   = array(
			'label'   => esc_html__( 'Polls per page', 'tspoll' ),
			'default' => 10,
			'option'  => 'ts_polls_per_page',
		);
		add_screen_option( $option, $args );
		$this->ts_poll_question_obj = new ts_poll_list_table();
	}

	public function ts_poll_admin_menu() {
		$hook = add_menu_page(
			$this->plugin_name,
			esc_html( 'TS Poll' ),
			'manage_options',
			'ts-poll',
			array( $this, 'get_ts_poll_admin_polls' ),
			esc_url( plugin_dir_url( __FILE__ ) . 'img/ts_poll_logo_sm.png' )
		);
		add_action( "load-$hook", array( $this, 'screen_option' ) );
	}

	public function ts_poll_admin_sub() {
		$hooks = add_submenu_page(
			'ts-poll',
			esc_html__( 'All TS Poll', 'tspoll' ),
			esc_html__( 'All Polls', 'tspoll' ),
			'manage_options',
			'ts-poll',
			array( $this, 'get_ts_poll_admin_polls' )
		);
		add_action( "load-$hooks", array( $this, 'screen_option' ) );
	}

	public function ts_poll_builder_sub() {
		add_submenu_page(
			'ts-poll',
			esc_html__( 'TS Poll Builder', 'tspoll' ),
			esc_html__( 'Add Poll', 'tspoll' ),
			'manage_options',
			'ts-poll-builder',
			array( $this, 'get_ts_poll_builder' )
		);
	}

	public function get_ts_poll_admin_polls() {
		include_once 'ts_poll_admin.php';
	}

	public function get_ts_poll_builder() {
		include_once 'ts_poll_builder.php';
	}
}
